@@ -191,7 +191,7 @@ class notion_connector:
 # Récupère la fonction pour avoir un obj de propriété
 #####################################################
 	def getProperties(self, elem):
-		return (get_properties()[elem['type']](elem))
+		return (get_properties(elem))
 
 ##################################################
 # Met à jour une propriété avec les elements voulu
