@@ -1,16 +1,13 @@
 def build_ret(elem):
 	ret = {
-		'type' : elem['type'],
 		'properties' : elem,
-		'update' : False,
-		'content' : False
+		'value' : None
 	}
 	return (ret)
 
 def ret_status(elem):
 	ret = build_ret(elem)
 	ret.update({
-		'content' : True,
 		'color' : elem['status']['color'],
 		'name' : elem['status']['name']
 	})
@@ -20,7 +17,6 @@ def ret_date(elem):
 	ret = build_ret(elem)
 	if elem['date'] != None:
 		ret.update({
-			'content' : True,
 			'start' : elem['date']['start'],
 			'end' : elem['date']['end']
 		})
@@ -30,7 +26,6 @@ def ret_formula(elem):
 	ret = build_ret(elem)
 	if elem['formula'] != None:
 		ret.update({
-			'content' : True,
 			'type' : 'number',
 			'number' : elem['formula']['number']
 		})
@@ -40,7 +35,6 @@ def ret_rich_text(elem):
 	ret = build_ret(elem)
 	if elem['rich_text'] != []:
 		ret.update({
-			'content' : True,
 			'rich_text' : elem['rich_text'][0]['plain_text']
 		})
 	return ret
@@ -49,7 +43,6 @@ def ret_title(elem):
 	ret = build_ret(elem)
 	if elem['title'] != []:
 		ret.update({
-			'content' : True,
 			'title' : elem['title'][0]['plain_text']
 		})
 	return ret
@@ -57,7 +50,6 @@ def ret_title(elem):
 def ret_number(elem):
 	ret = build_ret(elem)
 	ret.update({
-		'content' : True,
 		'number' : elem['number']
 	})
 	return ret
@@ -66,7 +58,6 @@ def ret_select(elem):
 	ret = build_ret(elem)
 	if elem['select'] != None:
 		ret.update({
-			'content' : True,
 			'color' : elem['select']['color'],
 			'name' : elem['select']['name']
 		})
@@ -75,7 +66,6 @@ def ret_select(elem):
 def ret_multi_select(elem):
 	ret = build_ret(elem)
 	ret.update({
-		'content' : True,
 		'multi_select' : []
 	})
 	for select in elem['multi_select']:
@@ -89,7 +79,6 @@ def ret_multi_select(elem):
 def ret_checkbox(elem):
 	ret = build_ret(elem)
 	ret.update({
-		'content' : True,
 		'checkbox' : elem['checkbox']
 	})
 	return ret
@@ -97,7 +86,6 @@ def ret_checkbox(elem):
 def ret_people(elem):
 	ret = build_ret(elem)
 	ret.update({
-		'content' : True,
 		'people' : []
 	})
 	for people in elem['people']:
@@ -108,7 +96,6 @@ def ret_url(elem):
 	ret = build_ret(elem)
 	if elem['url'] != None:
 		ret.update({
-			'content' : True,
 			'url' : elem['url']
 		})
 	return ret
@@ -116,7 +103,6 @@ def ret_url(elem):
 def ret_created_time(elem):
 	ret = build_ret(elem)
 	ret.update({
-		'content' : True,
 		'created_time' : elem['created_time']
 	})
 	return ret
@@ -124,7 +110,6 @@ def ret_created_time(elem):
 def ret_created_by(elem):
 	ret = build_ret(elem)
 	ret.update({
-		'content' : True,
 		'creator_id' : elem['created_by']['id'],
 		'creator_name' : elem['created_by']['name']
 	})
@@ -133,7 +118,6 @@ def ret_created_by(elem):
 def ret_last_edited_time(elem):
 	ret = build_ret(elem)
 	ret.update({
-		'content' : True,
 		'last_edited_time' : elem['last_edited_time']
 	})
 	return ret
@@ -141,7 +125,6 @@ def ret_last_edited_time(elem):
 def ret_last_edited_by(elem):
 	ret = build_ret(elem)
 	ret.update({
-		'content' : True,
 		'editor_id' : elem['last_edited_by']['id'],
 		'editor_name' : elem['last_edited_by']['name']
 	})
@@ -151,7 +134,6 @@ def ret_email(elem):
 	ret = build_ret(elem)
 	if elem['email'] != None:
 		ret.update({
-			'content' : True,
 			'email' : elem['email']
 		})
 	return ret
@@ -160,7 +142,6 @@ def ret_phone_number(elem):
 	ret = build_ret(elem)
 	if elem['phone_number'] != None:
 		ret.update({
-			'content' : True,
 			'phone_number' : elem['phone_number']
 		})
 	return ret
@@ -186,6 +167,5 @@ def get_properties(elem):
 		"last_edited_by" : ret_last_edited_by,
 		"formula" : ret_formula
 	}
-	print(elem)
 	ret = function[elem['type']](elem)
 	return ret
