@@ -117,9 +117,18 @@ class update_properties:
 						elem['properties']['people'].append(user)
 		return elem
 
+	def update_created_by(self, elem):
+		return elem
+
 	def update_last_edited_by(self, elem):
 		return elem
 
+	def update_last_edited_time(self, elem):
+		return(elem)
+
+	def update_created_time(self, elem):
+		return (elem)
+
 	def update_properties(self):
 		ret = {
 			"title" : self.update_title,
@@ -135,5 +144,8 @@ class update_properties:
 			"last_edited_by": self.update_last_edited_by,
 			"select" : self.update_select,
 			"status" : self.update_status,
+			"last_edited_time": self.update_last_edited_time,
+			"created_by": self.update_created_by,
+			"created_time": self.update_created_time
 		}
 		return ret
